-- Project : MTR390 - EMOS
-- Item/File Name : C2C_RECH.ADA, result_check.ads for GNAT/Unix
-- Authors: Paul Proudfoot, D.Hanske - EEEP, H. Pfoertner, TPMM / MTU-M
--
-- Change History :
-- 06.08.91: Created
-- 17.02.95: updated and file renamed
-- 07.03.95: prepared for separate fault counting
-- 13.03.95: parameter added to MIP_FAULT_COUNTING
-- 14.03.95: FIF_IDENT (from MCP) changed from BOOLEAN to SHORT
-- 10.09.96: Definition of subtype dam_vec
-- 27.02.97: Complete revision, introduction of thermal severities for
--           creep areas
-- 28.02.97: Realistic default values for fill-in factors
-- 03.03.97: Dimension of DAM_VEC defined in package stress_damage
-- 13.03.97: DAM_VEC replaced by type RESULT_ARRAY from stress_damage,
--           default value of FIF_IDENT set to 1
-- 10.04.97: FIFs for PT turbine blade adapted to changed creep coeffs
--
-- Description:  This package contains routines necessary for the result
--               check and correction.
--
-- Defined
-- Modules:     PERFORM
--              MIP_FAULT_COUNTING
--------------------------------------------------------------------------------

with Interfaces, Serv95, Data_Check, Stress_Damage;
use  Interfaces, Serv95;

--------------------------------------------------------------------------------

package Result_Check is

   -- The following global variables with initial values will be updated with
   -- actual values from the MCP in state INIT1, after the MCP data set has been
   -- identified as valid.

   Dropout_Amount : Integer_16 := 655; -- Scaling: 32768 
   Dropout_Time   : Integer_16 := 240; -- 2 minutes 
   -- constant part of fill-in factors (scaling 2048),
   -- factor for SEV_TH1 for creep areas 22, 33
   Fif_0 : Stress_Damage.Result_Array := Stress_Damage.Result_Array'(1 => 1946, 2 => 1024, 3 => 614, 4 => 1024, 9 .. 18 => 307, 19 => 246, 20 => 328, 21 => 0, 22 => 2167, 25 => 41, 26 => 225, 33 => 0, 35 => 1638, 36 => 778, 37 => 1516, 38 => 1352, 39 => 1393, -- Compressor impellers
-- HPT disk-- HPT blades-- HPT cover plate-- PT stage 1 blades-- PT disks
   others =>
   0);

   -- proportional part of fill-in factors (scaling 2048)
   -- factor for SEV_TH2 for creep areas 22, 33
   Fif_1 : Stress_Damage.Result_Array := Stress_Damage.Result_Array'(1 => 453, 2 => 780, 3 => 418, 4 => 154, 9 => 795, 10 .. 18 => 819, 19 => 530, 20 => 364, 21 => 899, 22 => 0, 25 => 1189, 26 => 538, 33 => 2048, 35 => 639, 36 => 464, 37 => 660, 38 => 520, 39 => 527, -
   - Compressor impellers-- HPT disk-- HPT blades-- HPT cover plate-- PT stage 1 blades-- PT disks
   others =>
   0);

   Fif_Ident : Integer_16 := 1;  
   Fif_Hlf   : Integer_16 := 8192; -- Scaling:2048 
   -- The fault counts are made global because they have to be
   -- placed in the result block EMA.
   Fault_Counts : array (Data_Check.Status_Index) of Integer_16 := 
     (
   others =>
   0);

   -- The following booleans are for the status message in MOP.

   Mip_Error         : Boolean := False;  
   Fatal_Mip_Error   : Boolean := False;  
   Cont_Mip_Error    : Boolean := False;  
   Mip_Error_High    : Boolean := False;  
   Dam_Incr_High     : Boolean := False;  
   No_Result_Checks  : Boolean := False;  
   Dam_Corr_By_Cm1   : Boolean := False;  
   Dam_Corr_By_Cm2   : Boolean := False;  
   No_Dam_Correction : Boolean := False;  
   -- Define booleans for CM errors
   Cm_Error  : Boolean := False;  
   Cm2_Error : Boolean := False;  
   -- Two global variables will be used to store the first faulty value with its
   -- corresponding area in the monitoring account set EMA .
   Result_Value : Integer_16 := 0;  
   Result_Area  : Integer_16 := 0;  
   -- Define the status of the result check which will be required in COUNT
   -- to discriminate whether time counting is normal or has to be counted as
   -- 'time without valid monitoring'.
   type Status_Of_Result_Check is 
         (Pass, 
          Fail); 


   --------------------------------------------------------------------------------

   procedure Mip_Fault_Counting (
         Mips_Status : in     Data_Check.Status_Data_Type 
       ); 

   --------------------------------------------------------------------------------

   procedure Perform (
         Sev_Cy_Own    : in     Integer_16;                 
         Sev_Cy_Other  : in     Integer_16;                 
         Sev_Th1_Own   : in     Integer_16;                 
         Sev_Th1_Other : in     Integer_16;                 
         Sev_Th2_Own   : in     Integer_16;                 
         Sev_Th2_Other : in     Integer_16;                 
         Runtime       : in     Integer_16;                 
         Damage        : in out Stress_Damage.Result_Array; 
         Status_Result :    out Status_Of_Result_Check      
       ); 

   --------------------------------------------------------------------------------

end Result_Check;